function qbranchpopulationdensities = importfile2(filename, dataLines)
%IMPORTFILE3 Import data from a text file
%  QBRANCHPOPULATIONDENSITIES = IMPORTFILE3(FILENAME) reads data from
%  text file FILENAME for the default selection.  Returns the numeric
%  data.
%
%  QBRANCHPOPULATIONDENSITIES = IMPORTFILE3(FILE, DATALINES) reads data
%  for the specified row interval(s) of text file FILENAME. Specify
%  DATALINES as a positive scalar integer or a N-by-2 array of positive
%  scalar integers for dis-contiguous row intervals.
%
%  Example:
%  qbranchpopulationdensities = importfile3("/home/he/1_PhD/2_nsAPPJ_Paper/1_Simulation/1_Validation/20230725_SimForPaperFiguresConcluAgain_lamda5e_19_gamma3e_3/20230430_SimForPaperFiguresAgain/20220610_3SetsPower_43p75Percent/1_VV/plot_0725/N2vib_2/plot_a2b2c2/0_data_A1_A2/240725_R1C8_N2v_ErrorBar/3kV_200ns/qbranch_population_densities.csv", [1, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 18-Aug-2024 22:07:58

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [1, Inf];
end

%% Set up the Import Options and import the data
opts = delimitedTextImportOptions("NumVariables", 19);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = [" ± ", ","];

% Specify column names and types
opts.VariableNames = ["time", "Trot", "N0", "N1", "N2", "N3", "N4", "N5", "N6", "N7", "VarName11", "VarName12", "VarName13", "VarName14", "VarName15", "VarName16", "VarName17", "VarName18", "VarName19"];
opts.VariableTypes = ["double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double", "double"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";
opts.ConsecutiveDelimitersRule = "join";

% Import the data
qbranchpopulationdensities = readtable(filename, opts);

%% Convert to output type
qbranchpopulationdensities = table2array(qbranchpopulationdensities);
end