function timeevolutionv0 = import_a2data(filename, dataLines)
%IMPORTFILE Import data from a text file
%  TIMEEVOLUTIONV0 = IMPORTFILE(FILENAME) reads data from text file
%  FILENAME for the default selection.  Returns the data as a cell array.
%
%  TIMEEVOLUTIONV0 = IMPORTFILE(FILE, DATALINES) reads data for the
%  specified row interval(s) of text file FILENAME. Specify DATALINES as
%  a positive scalar integer or a N-by-2 array of positive scalar
%  integers for dis-contiguous row intervals.
%
%  Example:
%  timeevolutionv0 = importfile("/home/he/1_PhD/phd/1_APPJ/0_Benchmarking/HeN2O2/2-HeN2/A2_Jan/2020-04/2_N2_pulse_Jan20200403/0_data_A1_A2/200228_2/time_evolution_v=0", [2, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 21-May-2020 12:11:18

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [2, Inf];
end

%% Setup the Import Options
opts = delimitedTextImportOptions("NumVariables", 2);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = " ";

% Specify column names and types
opts.VariableNames = ["Delay", "N"];
opts.VariableTypes = ["double", "double"];
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";
opts.ConsecutiveDelimitersRule = "join";
opts.LeadingDelimitersRule = "ignore";

% Import the data
timeevolutionv0 = readtable(filename, opts);

%% Convert to output type
timeevolutionv0 = table2cell(timeevolutionv0);
numIdx = cellfun(@(x) ~isnan(str2double(x)), timeevolutionv0);
timeevolutionv0(numIdx) = cellfun(@(x) {str2double(x)}, timeevolutionv0(numIdx));
end