function power = importfile1(filename, dataLines)
%IMPORTFILE1 Import data from a text file
%  POWER = IMPORTFILE1(FILENAME) reads data from text file FILENAME for
%  the default selection.  Returns the numeric data.
%
%  POWER = IMPORTFILE1(FILE, DATALINES) reads data for the specified row
%  interval(s) of text file FILENAME. Specify DATALINES as a positive
%  scalar integer or a N-by-2 array of positive scalar integers for
%  dis-contiguous row intervals.
%
%  Example:
%  power = importfile1("/home/he/1_PhD/phd/1_APPJ/0_Benchmarking/HeN2O2/2-HeN2/A2_Jan/2020-04/2_N2_pulse_Jan20200403_2/0_data_A1_A2/power.txt", [4, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 21-May-2020 23:40:29

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [4, Inf];
end

%% Setup the Import Options
opts = delimitedTextImportOptions("NumVariables", 2);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = "\t";

% Specify column names and types
opts.VariableNames = ["COMMENT", "VarName2"];
opts.VariableTypes = ["double", "double"];
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";

% Import the data
power = readtable(filename, opts);

%% Convert to output type
power = table2array(power);
end